from OSMPythonTools.api import Api
from OSMPythonTools.overpass import Overpass, overpassQueryBuilder, Nominatim
from dataclasses import dataclass
from pydantic import BaseModel


# Defines the landmark class (aka some place there is to visit)
@dataclass
class Landmarkkkk :
    name : str
    attractiveness : int
    id : int
    
class Landmark(BaseModel) :
    name : str
    attractiveness : int
    loc : tuple

# Converts a OSM id to a landmark
def add_from_id(id: int, score: int) :

    try :
        s = 'way/' + str(id)           # prepare string for query
        obj =  api.query(s)                             # object to add
    except :
        s = 'relation/' + str(id)           # prepare string for query
        obj =  api.query(s)                             # object to add

    return Landmarkkkk(obj.tag('name:fr'), score, id)      # create Landmark out of it


def get_sights(city_country: str):
    nominatim = Nominatim()
    areaId = nominatim.query(city_country).areaId()
    overpass = Overpass()

    # list of stuff we want to define as sights
    l = ["'tourism'='museum'", "'tourism'='attraction'", "'tourism'='gallery'", 'historic', "'amenity'='arts_centre'", "'amenity'='planetarium'", '"amenity"="place_of_worship"'] 
    score = 0

    for amenity in l :
        query = overpassQueryBuilder(area=areaId, elementType=['way', 'relation'], selector=amenity, includeGeometry=True)
        result = overpass.query(query)
        score += result.countElements()

    return score


# take a lsit of tuples (id, score) to generate a list of landmarks
def generate_landmarks(ids_and_scores: list) :

    L = []
    for tup in ids_and_scores :
        L.append(add_from_id(tup[0], tup[1]))

    return L
"""
api = Api()


l = (7515426, 70)
t = (5013364, 100)
n = (201611261, 99)
a = (226413508, 50)
m = (23762981, 30)


ids_and_scores = [t, l, n, a, m]

landmarks = generate_landmarks(ids_and_scores)


for obj in landmarks :
    print(obj)"""



print(get_sights('Paris, France'))